Credits
=======

Development Lead
----------------

* Kalyan Veeramachaneni <kalyan@mit.edu>
* Carles Sala <csala@csail.mit.edu>

Contributors
------------

* Hector Dominguez <hedb_12@hotmail.com>
* Plamen Valentinov <pvkdeveloper@gmx.com>
* Ihssan Tinawi <itinawi@mit.edu>
* Rodrigo Diez <rjdiez@mit.edu>
* Katherine Wang <wang19k@mit.edu>
* Van Coykendall <vcoyk@mit.edu>
* Max Kanter <kmax12@gmail.com>
* Sze Nga Wong <wsnalice@mit.edu>
* Bryan Farris <bryanfarris@gmail.com>
